<?php

/*

Copyright 2014 Dario Curvino (email : d.curvino@tiscali.it)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>
*/

if (!defined('ABSPATH')) {
    exit('You\'re not allowed to see this page');
} // Exit if accessed directly

if(!is_admin()) {
    return;
}

//e.g. http://localhost/plugin_development/wp-content/plugins/yet-another-stars-rating/admin/js/
define('YASR_JS_DIR_ADMIN', plugins_url() . '/' . YASR_RELATIVE_PATH_ADMIN . '/js/');
//CSS directory absolute URL
define('YASR_CSS_DIR_ADMIN', plugins_url() . '/' . YASR_RELATIVE_PATH_ADMIN . '/css/');

require YASR_ABSOLUTE_PATH_ADMIN . '/yasr-update-functions.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/yasr-admin-functions.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/yasr-admin-actions.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/yasr-admin-actions-ajax.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/yasr-admin-filters.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/class-wp-list-table.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/settings/yasr-settings-functions-misc.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/settings/yasr-settings-functions.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/editor/yasr-editor-functions.php';
require YASR_ABSOLUTE_PATH_ADMIN . '/editor/YasrOnSavePost.php';

/**
 * Callback function for the spl_autoload_register above.
 *
 * @param $class
 */
function yasr_autoload_admin_classes($class) {
    /**
     * If the class being requested does not start with 'Yasr' prefix,
     * it's not in Yasr Project
     */
    if (0 !== strpos($class, 'Yasr')) {
        return;
    }
    $file_name =  YASR_ABSOLUTE_PATH_ADMIN . '/classes/' . $class . '.php';

    // check if file exists, just to be sure
    if (file_exists($file_name)) {
        require($file_name);
    }
}

//AutoLoad Yasr Shortcode Classes, only when a object is created
spl_autoload_register('yasr_autoload_admin_classes');

add_action('admin_enqueue_scripts', 'yasr_add_admin_scripts');

//$hook contain the current page in the admin side
function yasr_add_admin_scripts($hook) {

    global $yasr_settings_page;

    if ($hook === 'post.php' || $hook === 'post-new.php') {
        wp_enqueue_script(
            'yasr_classic_editor_functions',
            YASR_JS_DIR_ADMIN . 'yasr-editor-screen.js',
            array('jquery'),
            YASR_VERSION_NUM,
            true
        );
    }

    if ($hook === 'index.php' || $hook === 'edit.php' || $hook === 'post.php' || $hook === 'post-new.php' ||
        $hook === 'edit-comments.php' || $hook === $yasr_settings_page ||
        $hook === 'yet-another-stars-rating_page_yasr_stats_page'
    ) {

        do_action('yasr_add_admin_scripts_begin');

        $rater_file_to_include = 'rater-js.js';

        if (is_rtl()) {
            $rater_file_to_include = 'rater-js-rtl.js';
        }

        wp_enqueue_style(
            'yasrcss',
            YASR_CSS_DIR_ADMIN . 'yasr-admin.css',
            false,
            YASR_VERSION_NUM,
            'all'
        );

        wp_enqueue_script(
            'yasradmin',
            YASR_JS_DIR_ADMIN . 'yasr-admin.js',
            array('jquery'),
            YASR_VERSION_NUM,
            true
        );

        wp_enqueue_script(
            'rater',
            YASR_JS_DIR_INCLUDES .
            $rater_file_to_include,
            '',
            YASR_VERSION_NUM,
            true
        );

        do_action('yasr_add_admin_scripts_end', $hook);

        $yasr_loader = YASR_IMG_DIR . 'loader.gif';

        wp_localize_script(
            'yasradmin', 'yasrCommonDataAdmin',
            array(
                'loaderHtml' => $yasr_loader
            )
        );

    }

}

/* Hook to admin_menu the yasr_add_pages function above */
add_action('admin_menu', 'yasr_add_pages');

function yasr_add_pages() {

    global $yasr_settings_page;

    //Add Settings Page
    $yasr_settings_page = add_menu_page(
        __('Yet Another Stars Rating: settings', 'yet-another-stars-rating'), //Page Title
        __('Yet Another Stars Rating', 'yet-another-stars-rating'), //Menu Title
        'manage_options', //capability
        'yasr_settings_page', //menu slug
        'yasr_settings_page_callback', //The function to be called to output the content for this page.
        'dashicons-star-half'
    );

    add_submenu_page(
        'yasr_settings_page',
        'Yet Another Stars Rating: settings',
        'Settings',
        'manage_options',
        'yasr_settings_page'
    );

    add_submenu_page(
        'yasr_settings_page',
        'Yet Another Stars Rating: All Rating',
        'Stats',
        'manage_options',
        'yasr_stats_page',
        'yasr_stats_page_callback'
    );

    if (yasr_fs()->is_free_plan() && !yasr_fs()->is_trial()) {
        global $submenu;
        $permalink                       = '#';
        $contact_us_string               = sprintf(
            __('Contact Us %s', 'yet-another-stars-rating'),
            '<span class="dashicons dashicons-lock" />'
        );
        $submenu['yasr_settings_page'][] = array($contact_us_string, 'manage_options', $permalink);
    }

}

// Settings Page Content
function yasr_settings_page_callback() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.', 'yet-another-stars-rating'));
    }
    include(YASR_ABSOLUTE_PATH_ADMIN . '/settings/yasr-settings-page.php');
} //End yasr_settings_page_content


function yasr_stats_page_callback() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.', 'yet-another-stars-rating'));
    }

    include(YASR_ABSOLUTE_PATH_ADMIN . '/yasr-stats-page.php');
}
